# PR: appcypher/awesome-mcp-servers — Add GraQle

## Target Repo
https://github.com/appcypher/awesome-mcp-servers

## Category
**Developer Tools**

## Entry to Add

```markdown
- [graqle](https://github.com/quantamixsol/graqle) - Code intelligence MCP server that builds knowledge graphs from codebases. Provides 16 tools for dependency analysis, impact analysis, institutional memory, and governed AI reasoning. Supports Claude Code, Cursor, VS Code Copilot. 14 LLM backends, fully offline.
```

## PR Title
Add graqle — architecture-aware code intelligence MCP server

## How to Submit
1. Fork `appcypher/awesome-mcp-servers`
2. Add entry under Developer Tools
3. Open PR with brief description
